==> zio-aws-ssm_3-5.17.102.7-sources.jar: zio/aws/ssm/model/DeregisterTargetFromMaintenanceWindowResponse.scala <==
package zio.aws.ssm.model
import zio.aws.ssm.model.primitives.{
  MaintenanceWindowTargetId,
  MaintenanceWindowId
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class DeregisterTargetFromMaintenanceWindowResponse(
    windowId: Option[MaintenanceWindowId] = None,
    windowTargetId: Option[MaintenanceWindowTargetId] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssm.model.DeregisterTargetFromMaintenanceWindowResponse = {
    import DeregisterTargetFromMaintenanceWindowResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssm.model.DeregisterTargetFromMaintenanceWindowResponse
      .builder()
      .optionallyWith(
        windowId.map(value =>
          MaintenanceWindowId.unwrap(value): java.lang.String
        )
      )(_.windowId)
      .optionallyWith(
        windowTargetId.map(value =>
          MaintenanceWindowTargetId.unwrap(value): java.lang.String
        )
      )(_.windowTargetId)
      .build()
  }
  def asReadOnly
      : zio.aws.ssm.model.DeregisterTargetFromMaintenanceWindowResponse.ReadOnly =
    zio.aws.ssm.model.DeregisterTargetFromMaintenanceWindowResponse
      .wrap(buildAwsValue())
}
object DeregisterTargetFromMaintenanceWindowResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssm.model.DeregisterTargetFromMaintenanceWindowResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ssm.model.DeregisterTargetFromMaintenanceWindowResponse =
      zio.aws.ssm.model.DeregisterTargetFromMaintenanceWindowResponse(
        windowId.map(value => value),
        windowTargetId.map(value => value)
      )
    def windowId: Option[MaintenanceWindowId]
    def windowTargetId: Option[MaintenanceWindowTargetId]
    def getWindowId: ZIO[Any, AwsError, MaintenanceWindowId] =
      AwsError.unwrapOptionField("windowId", windowId)
    def getWindowTargetId: ZIO[Any, AwsError, MaintenanceWindowTargetId] =
      AwsError.unwrapOptionField("windowTargetId", windowTargetId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssm.model.DeregisterTargetFromMaintenanceWindowResponse
  ) extends zio.aws.ssm.model.DeregisterTargetFromMaintenanceWindowResponse.ReadOnly {
    override val windowId: Option[MaintenanceWindowId] = scala
      .Option(impl.windowId())
      .map(value => zio.aws.ssm.model.primitives.MaintenanceWindowId(value))
    override val windowTargetId: Option[MaintenanceWindowTargetId] = scala
      .Option(impl.windowTargetId())
      .map(value =>
        zio.aws.ssm.model.primitives.MaintenanceWindowTargetId(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssm.model.DeregisterTargetFromMaintenanceWindowResponse
  ): zio.aws.ssm.model.DeregisterTargetFromMaintenanceWindowResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ssm_3-5.19.31.3-sources.jar: zio/aws/ssm/model/DeregisterTargetFromMaintenanceWindowResponse.scala <==
package zio.aws.ssm.model
import zio.aws.ssm.model.primitives.{
  MaintenanceWindowTargetId,
  MaintenanceWindowId
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DeregisterTargetFromMaintenanceWindowResponse(
    windowId: Optional[MaintenanceWindowId] = Optional.Absent,
    windowTargetId: Optional[MaintenanceWindowTargetId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssm.model.DeregisterTargetFromMaintenanceWindowResponse = {
    import DeregisterTargetFromMaintenanceWindowResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssm.model.DeregisterTargetFromMaintenanceWindowResponse
      .builder()
      .optionallyWith(
        windowId.map(value =>
          MaintenanceWindowId.unwrap(value): java.lang.String
        )
      )(_.windowId)
      .optionallyWith(
        windowTargetId.map(value =>
          MaintenanceWindowTargetId.unwrap(value): java.lang.String
        )
      )(_.windowTargetId)
      .build()
  }
  def asReadOnly
      : zio.aws.ssm.model.DeregisterTargetFromMaintenanceWindowResponse.ReadOnly =
    zio.aws.ssm.model.DeregisterTargetFromMaintenanceWindowResponse
      .wrap(buildAwsValue())
}
object DeregisterTargetFromMaintenanceWindowResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssm.model.DeregisterTargetFromMaintenanceWindowResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ssm.model.DeregisterTargetFromMaintenanceWindowResponse =
      zio.aws.ssm.model.DeregisterTargetFromMaintenanceWindowResponse(
        windowId.map(value => value),
        windowTargetId.map(value => value)
      )
    def windowId: Optional[MaintenanceWindowId]
    def windowTargetId: Optional[MaintenanceWindowTargetId]
    def getWindowId: ZIO[Any, AwsError, MaintenanceWindowId] =
      AwsError.unwrapOptionField("windowId", windowId)
    def getWindowTargetId: ZIO[Any, AwsError, MaintenanceWindowTargetId] =
      AwsError.unwrapOptionField("windowTargetId", windowTargetId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssm.model.DeregisterTargetFromMaintenanceWindowResponse
  ) extends zio.aws.ssm.model.DeregisterTargetFromMaintenanceWindowResponse.ReadOnly {
    override val windowId: Optional[MaintenanceWindowId] = zio.aws.core.internal
      .optionalFromNullable(impl.windowId())
      .map(value => zio.aws.ssm.model.primitives.MaintenanceWindowId(value))
    override val windowTargetId: Optional[MaintenanceWindowTargetId] =
      zio.aws.core.internal
        .optionalFromNullable(impl.windowTargetId())
        .map(value =>
          zio.aws.ssm.model.primitives.MaintenanceWindowTargetId(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssm.model.DeregisterTargetFromMaintenanceWindowResponse
  ): zio.aws.ssm.model.DeregisterTargetFromMaintenanceWindowResponse.ReadOnly =
    new Wrapper(impl)
}
